@@ -1,9 +1,10 @@
 #!/usr/bin/env python
-import sys, tempfile, os, shutil, StringIO
+import sys, tempfile, os, shutil, imp
 import unittest
 import logging
 import warnings
 from xml.dom import minidom
+from io import BytesIO
 warnings.filterwarnings("ignore", message = 'The CObject type')
 
 # Catch silly mistakes...
@@ -19,7 +20,7 @@ from zeroinstall.support import basedir, tasks
 
 dpkgdir = os.path.join(os.path.dirname(__file__), 'dpkg')
 
-empty_feed = qdom.parse(StringIO.StringIO("""<interface xmlns='http://zero-install.sourceforge.net/2004/injector/interface'>
+empty_feed = qdom.parse(BytesIO(b"""<interface xmlns='http://zero-install.sourceforge.net/2004/injector/interface'>
 <name>Empty</name>
 <summary>just for testing</summary>
 </interface>"""))
@@ -66,16 +67,11 @@ class DummyHandler(handler.Handler):
 		self.ex = None
 		self.allow_downloads = False
 
-	def get_download(self, url, force = False, hint = None, factory = None):
-		if self.allow_downloads:
-			return handler.Handler.get_download(self, url, force, hint, factory)
-		raise model.SafeException("DummyHandler: " + url)
-
 	def wait_for_blocker(self, blocker):
 		self.ex = None
 		handler.Handler.wait_for_blocker(self, blocker)
 		if self.ex:
-			raise self.ex, None, self.tb
+			support.raise_with_traceback(self.ex, self.tb)
 
 	def report_error(self, ex, tb = None):
 		assert self.ex is None, self.ex
@@ -173,7 +169,7 @@ class BaseTest(unittest.TestCase):
 		os.environ['XDG_CONFIG_DIRS'] = ''
 		os.environ['XDG_CACHE_HOME'] = self.cache_home
 		os.environ['XDG_CACHE_DIRS'] = self.cache_system
-		reload(basedir)
+		imp.reload(basedir)
 		assert basedir.xdg_config_home == self.config_home
 
 		os.mkdir(self.config_home, 0o700)
@@ -202,7 +198,8 @@ class BaseTest(unittest.TestCase):
 		my_dbus.system_services = {}
 
 	def tearDown(self):
-		assert self.config.handler.ex is None, self.config.handler.ex
+		if self.config.handler.ex:
+			support.raise_with_traceback(self.config.handler.ex, self.config.handler.tb)
 
 		shutil.rmtree(self.config_home)
 		support.ro_rmtree(self.cache_home)
