@@ -144,7 +144,7 @@ class TestDownload(BaseTest):
 			rootLogger.setLevel(WARN)
 
 		hello = self.config.iface_cache.get_feed('http://localhost:8000/Hello')
-		self.assertEquals(None, hello)
+		self.assertEqual(None, hello)
 
 		with output_suppressed():
 			run_server('6FCF121BE2390E0B.gpg')
@@ -156,7 +156,7 @@ class TestDownload(BaseTest):
 
 			# Check we imported the interface after trusting the key
 			hello = self.config.iface_cache.get_feed('http://localhost:8000/Hello', force = True)
-			self.assertEquals(1, len(hello.implementations))
+			self.assertEqual(1, len(hello.implementations))
 
 			# Shouldn't need to prompt the second time
 			sys.stdin = None
@@ -164,7 +164,7 @@ class TestDownload(BaseTest):
 
 	def testSelections(self):
 		from zeroinstall.injector import cli
-		root = qdom.parse(file("selections.xml"))
+		root = qdom.parse(open("selections.xml"))
 		sels = selections.Selections(root)
 		class Options: dry_run = False
 
@@ -195,7 +195,7 @@ class TestDownload(BaseTest):
 
 	def testSelectionsWithFeed(self):
 		from zeroinstall.injector import cli
-		root = qdom.parse(file("selections.xml"))
+		root = qdom.parse(open("selections.xml"))
 		sels = selections.Selections(root)
 
 		with output_suppressed():
@@ -282,7 +282,7 @@ class TestDownload(BaseTest):
 		old_out = sys.stdout
 		try:
 			sys.stdout = StringIO()
-			run_server(('HelloWorld.tar.bz2', 'dummy_1-1_all.deb'))
+			run_server(('HelloWorld.tar.bz2', 'redirect/dummy_1-1_all.deb', 'dummy_1-1_all.deb'))
 			policy = Policy(os.path.abspath('Recipe.xml'), config = self.config)
 			try:
 				download_and_execute(policy, [])
@@ -305,7 +305,7 @@ class TestDownload(BaseTest):
 			except model.SafeException as ex:
 				if 'Attempt to unpack dir over symlink "HelloWorld"' not in str(ex):
 					raise
-			self.assertEquals(None, basedir.load_first_cache('0install.net', 'implementations', 'main'))
+			self.assertEqual(None, basedir.load_first_cache('0install.net', 'implementations', 'main'))
 		finally:
 			sys.stdout = old_out
 
@@ -362,7 +362,7 @@ class TestDownload(BaseTest):
 			getLogger().setLevel(ERROR)
 			iface = self.config.iface_cache.get_interface('http://example.com:8000/Hello.xml')
 			mtime = int(os.stat('Hello-new.xml').st_mtime)
-			self.config.iface_cache.update_feed_from_network(iface.uri, file('Hello-new.xml').read(), mtime + 10000)
+			self.config.iface_cache.update_feed_from_network(iface.uri, open('Hello-new.xml').read(), mtime + 10000)
 
 			trust.trust_db.trust_key('DE937DD411906ACF7C263B396FCF121BE2390E0B', 'example.com:8000')
 			run_server(server.Give404('/Hello.xml'), 'latest.xml', '/0mirror/keys/6FCF121BE2390E0B.gpg', 'Hello.xml')
@@ -382,7 +382,7 @@ class TestDownload(BaseTest):
 				assert "New feed's modification time is before old version" in str(ex)
 
 			# Must finish with the newest version
-			self.assertEquals(1235911552, self.config.iface_cache._get_signature_date(iface.uri))
+			self.assertEqual(1235911552, self.config.iface_cache._get_signature_date(iface.uri))
 		finally:
 			sys.stdout = old_out
 
@@ -430,7 +430,7 @@ class TestDownload(BaseTest):
 					background.spawn_background_update(p, verbose)
 					assert False
 				except SystemExit as ex:
-					self.assertEquals(1, ex.code)
+					self.assertEqual(1, ex.code)
 			finally:
 				os._exit = old_exit
 				config.DEFAULT_KEY_LOOKUP_SERVER = key_info
