@@ -3,6 +3,7 @@
 
 import gtk
 from dialog import Template
+from zeroinstall import _
 from zeroinstall.gtkui import help_box
 from zeroinstall.injector.model import network_levels
 from zeroinstall.injector import trust, gpg
@@ -11,51 +12,55 @@ from freshness import freshness_levels, Freshness
 SHOW_CACHE = 0
 
 class Preferences:
-	def __init__(self, policy):
+	def __init__(self, config, notify_cb = None):
+		if notify_cb is None:
+			notify_cb = lambda: None
+
+		def connect_toggle(widget_name, setting_name):
+			widget = widgets.get_widget(widget_name)
+			widget.set_active(getattr(config, setting_name))
+			def toggle(w, config = config, setting_name = setting_name):
+				setattr(config, setting_name, w.get_active())
+				config.save_globals()
+				notify_cb()
+			widget.connect('toggled', toggle)
+
 		widgets = Template('preferences_box')
 
 		self.window = widgets.get_widget('preferences_box')
 		self.window.connect('destroy', lambda w: self.destroyed())
 
 		network = widgets.get_widget('network_use')
-		network.set_active(list(network_levels).index(policy.network_use))
+		network.set_active(list(network_levels).index(config.network_use))
 
 		def set_network_use(combo):
-			policy.network_use = network_levels[network.get_active()]
-			policy.save_config()
-			policy.solve_with_downloads()
+			config.network_use = network_levels[network.get_active()]
+			config.save_globals()
+			notify_cb()
 		network.connect('changed', set_network_use)
 
 		# Freshness
 		times = [x.time for x in freshness_levels]
-		if policy.freshness not in times:
-			freshness_levels.append(Freshness(policy.freshness,
-							  '%d seconds' % policy.freshness))
-			times.append(policy.freshness)
-		eb = gtk.EventBox()	# For the tooltip
+		if config.freshness not in times:
+			freshness_levels.append(Freshness(config.freshness,
+							  '%d seconds' % config.freshness))
+			times.append(config.freshness)
 		freshness = widgets.get_widget('freshness')
 		for level in freshness_levels:
 			freshness.append_text(str(level))
-		freshness.set_active(times.index(policy.freshness))
+		freshness.set_active(times.index(config.freshness))
 		def set_freshness(combo, freshness = freshness): # (pygtk bug?)
-			policy.freshness = freshness_levels[freshness.get_active()].time
-			policy.save_config()
-			import main
-			main.recalculate()
+			config.freshness = freshness_levels[freshness.get_active()].time
+			config.save_globals()
+			notify_cb()
 		freshness.connect('changed', set_freshness)
 
-		stable_toggle = widgets.get_widget('help_test')
-		stable_toggle.set_active(policy.help_with_testing)
-		def toggle_stability(toggle):
-			policy.help_with_testing = toggle.get_active()
-			policy.save_config()
-			import main
-			main.recalculate()
-		stable_toggle.connect('toggled', toggle_stability)
+		connect_toggle('help_test', 'help_with_testing')
 
 		# Keys
 		keys_view = widgets.get_widget('trusted_keys')
 		KeyList(keys_view)
+		connect_toggle('auto_approve', 'auto_approve_keys')
 
 		# Responses
 		self.window.set_default_response(gtk.RESPONSE_CLOSE)
@@ -147,11 +152,11 @@ class KeyList:
 		tv.connect('button-press-event', trusted_keys_button_press)
 
 preferences_box = None
-def show_preferences(policy):
+def show_preferences(config, notify_cb = None):
 	global preferences_box
 	if preferences_box:
 		preferences_box.destroy()
-	preferences_box = Preferences(policy)
+	preferences_box = Preferences(config, notify_cb)
 	preferences_box.window.show()
 	return preferences_box.window
 		
@@ -186,5 +191,11 @@ click on 'Interface Properties'. See that dialog's help text for more informatio
 _("""This section lists all keys which you currently trust. When fetching a new program or \
 updates for an existing one, the feed must be signed by one of these keys. If not, \
 you will be prompted to confirm that you trust the new key, and it will then be added \
-to this list. To remove a key, right-click on it and choose 'Remove' from the menu.""")),
+to this list.
+
+If "Automatic approval for new feeds" is on, new keys will be automatically approved if \
+you haven't used the program before and the key is known to the key information server. \
+When updating feeds, confirmation for new keys is always required.
+
+To remove a key, right-click on it and choose 'Remove' from the menu.""")),
 )
