@@ -3,9 +3,9 @@
 
 import zeroinstall
 import os
+from zeroinstall import _
 from zeroinstall.support import tasks
 from zeroinstall.injector.model import Interface, Feed, stable, testing, developer, stability_levels
-from zeroinstall.injector.iface_cache import iface_cache
 from zeroinstall.injector import writer, namespaces, gpg
 from zeroinstall.gtkui import help_box
 
@@ -16,7 +16,6 @@ from dialog import DialogResponse, Template
 from impl_list import ImplementationList
 import time
 import dialog
-import compile
 
 _dialogs = {}	# Interface -> Properties
 
@@ -31,11 +30,11 @@ def format_para(para):
 	return ' '.join(lines)
 
 def have_source_for(policy, interface):
+	iface_cache = policy.config.iface_cache
 	# Note: we don't want to actually fetch the source interfaces at
 	# this point, so we check whether:
 	# - We have a feed of type 'src' (not fetched), or
 	# - We have a source implementation in a regular feed
-	have_src = False
 	for f in iface_cache.get_feed_imports(interface):
 		if f.machine == 'src':
 			return True
@@ -74,10 +73,10 @@ class Description:
 		try:
 			from locale import nl_langinfo, D_T_FMT
 			return time.strftime(nl_langinfo(D_T_FMT), time.localtime(secs))
-		except ImportError, ValueError:
+		except (ImportError, ValueError):
 			return time.ctime(secs)
 
-	def set_details(self, feed):
+	def set_details(self, iface_cache, feed):
 		buffer = self.buffer
 		heading_style = self.heading_style
 
@@ -207,6 +206,8 @@ class Feeds:
 		sel.select_path((0,))
 	
 	def build_model(self):
+		iface_cache = self.policy.config.iface_cache
+
 		usable_feeds = frozenset(self.policy.usable_feeds(self.interface))
 		unusable_feeds = frozenset(iface_cache.get_feed_imports(self.interface)) - usable_feeds
 
@@ -219,6 +220,8 @@ class Feeds:
 		return out
 
 	def sel_changed(self, sel):
+		iface_cache = self.policy.config.iface_cache
+
 		model, miter = sel.get_selected()
 		if not miter: return	# build in progress
 		feed_url = model[miter][Feeds.URI]
@@ -230,9 +233,9 @@ class Feeds:
 					enable_remove = True
 		self.remove_feed_button.set_sensitive( enable_remove )
 		try:
-			self.description.set_details(iface_cache.get_feed(feed_url))
-		except zeroinstall.SafeException, ex:
-			self.description.set_details(ex)
+			self.description.set_details(iface_cache, iface_cache.get_feed(feed_url))
+		except zeroinstall.SafeException as ex:
+			self.description.set_details(iface_cache, ex)
 	
 	def updated(self):
 		new_lines = self.build_model()
@@ -251,7 +254,7 @@ class Properties:
 	window = None
 	policy = None
 
-	def __init__(self, policy, interface, show_versions = False):
+	def __init__(self, policy, interface, compile, show_versions = False):
 		self.policy = policy
 
 		widgets = Template('interface_properties')
@@ -264,7 +267,7 @@ class Properties:
 		window.set_default_size(-1, gtk.gdk.screen_height() / 3)
 
 		self.compile_button = widgets.get_widget('compile')
-		self.compile_button.connect('clicked', lambda b: compile.compile(policy, interface))
+		self.compile_button.connect('clicked', lambda b: compile(interface))
 		window.set_default_response(gtk.RESPONSE_CANCEL)
 
 		def response(dialog, resp):
@@ -342,6 +345,8 @@ class Properties:
 @tasks.async
 def add_remote_feed(policy, parent, interface):
 	try:
+		iface_cache = policy.config.iface_cache
+
 		d = gtk.MessageDialog(parent, 0, gtk.MESSAGE_QUESTION, gtk.BUTTONS_CANCEL,
 			_('Enter the URL of the new source of implementations of this interface:'))
 		d.add_button(gtk.STOCK_ADD, gtk.RESPONSE_OK)
@@ -409,12 +414,12 @@ def add_remote_feed(policy, parent, interface):
 							d.destroy()
 							import main
 							main.recalculate()
-				except zeroinstall.SafeException, ex:
+				except zeroinstall.SafeException as ex:
 					error(str(ex))
 			else:
 				d.destroy()
 				return
-	except Exception, ex:
+	except Exception as ex:
 		import traceback
 		traceback.print_exc()
 		policy.handler.report_error(ex)
@@ -439,7 +444,7 @@ def add_local_feed(policy, interface):
 			reader.update_from_cache(interface)
 			import main
 			main.recalculate()
-		except Exception, ex:
+		except Exception as ex:
 			dialog.alert(None, _("Error in feed file '%(feed)s':\n\n%(exception)s") % {'feed': feed, 'exception': str(ex)})
 
 	def check_response(widget, response):
@@ -451,11 +456,11 @@ def add_local_feed(policy, interface):
 	chooser.connect('response', check_response)
 	chooser.show()
 
-def edit(policy, interface, show_versions = False):
+def edit(policy, interface, compile, show_versions = False):
 	assert isinstance(interface, Interface)
 	if interface in _dialogs:
 		_dialogs[interface].destroy()
-	_dialogs[interface] = Properties(policy, interface, show_versions)
+	_dialogs[interface] = Properties(policy, interface, compile, show_versions = show_versions)
 	_dialogs[interface].show()
 
 properties_help = help_box.HelpBox(_("Injector Properties Help"),
