@@ -438,6 +438,8 @@ class DebianDistribution(Distribution):
 			version, debarch, status = line.split('\t', 2)
 			if not status.endswith(' installed'): continue
 			clean_version = try_cleanup_distro_version(version)
+			if debarch.find("-") != -1:
+				debarch = debarch.split("-")[-1]
 			if clean_version:
 				return '%s\t%s' % (clean_version, canonical_machine(debarch.strip()))
 			else:
@@ -591,6 +593,43 @@ class SlackDistribution(Distribution):
 	def get_score(self, disto_name):
 		return int(disto_name == 'Slack')
 
+class ArchDistribution(Distribution):
+	"""An Arch Linux distribution."""
+
+	def __init__(self, packages_dir):
+		self._packages_dir = os.path.join(packages_dir, "local")
+
+	def get_package_info(self, package, factory):
+		# Add installed versions...
+		for entry in os.listdir(self._packages_dir):
+			name, version, build = entry.rsplit('-', 2)
+			if name == package:
+				gotarch = False
+				for line in open(os.path.join(self._packages_dir, entry, "desc")):
+					if line == "%ARCH%\n":
+						gotarch = True
+						continue
+					if gotarch:
+						arch = line.strip()
+						break
+				zi_arch = canonical_machine(arch)
+				clean_version = try_cleanup_distro_version("%s-%s" % (version, build))
+				if not clean_version:
+					warn(_("Can't parse distribution version '%(version)s' for package '%(package)s'"), {'version': version, 'package': name})
+					continue
+	
+				impl = factory('package:arch:%s:%s:%s' % \
+						(package, clean_version, zi_arch))
+				impl.version = model.parse_version(clean_version)
+				if zi_arch != '*':
+					impl.machine = zi_arch
+
+		# Add any uninstalled candidates found by PackageKit
+		self.packagekit.get_candidates(package, factory, 'package:arch')
+
+	def get_score(self, disto_name):
+		return int(disto_name == 'Arch')
+
 class GentooDistribution(Distribution):
 
 	def __init__(self, pkgdir):
@@ -730,11 +769,17 @@ def get_host_distribution():
 	if not _host_distribution:
 		dpkg_db_status = '/var/lib/dpkg/status'
 		pkgcache = '/var/cache/apt/pkgcache.bin'
-		_rpm_db = '/var/lib/rpm/Packages'
+		rpm_db_packages = '/var/lib/rpm/Packages'
 		_slack_db = '/var/log/packages'
+		_arch_db = '/var/lib/pacman'
 		_pkg_db = '/var/db/pkg'
 		_macports_db = '/opt/local/var/macports/registry/registry.db'
 
+		if sys.prefix == "/sw":
+			dpkg_db_status = os.path.join(sys.prefix, dpkg_db_status)
+			pkgcache = os.path.join(sys.prefix, pkgcache)
+			rpm_db_packages = os.path.join(sys.prefix, rpm_db_packages)
+
 		if os.name == "nt":
 			_host_distribution = WindowsDistribution()
 		elif os.path.isdir(_pkg_db):
@@ -742,14 +787,18 @@ def get_host_distribution():
 				_host_distribution = GentooDistribution(_pkg_db)
 			elif sys.platform.startswith("freebsd"):
 				_host_distribution = PortsDistribution(_pkg_db)
-		elif os.path.isfile(_macports_db):
-			_host_distribution = MacPortsDistribution(_macports_db)
-		elif os.access(dpkg_db_status, os.R_OK):
+		elif os.path.isfile(_macports_db) \
+			and sys.prefix.startswith("/opt/local"):
+				_host_distribution = MacPortsDistribution(_macports_db)
+		elif os.access(dpkg_db_status, os.R_OK) \
+			and os.path.getsize(dpkg_db_status) > 0:
 			_host_distribution = DebianDistribution(dpkg_db_status, pkgcache)
-		elif os.path.isfile(_rpm_db):
-			_host_distribution = RPMDistribution(_rpm_db)
+		elif os.path.isfile(rpm_db_packages):
+			_host_distribution = RPMDistribution(rpm_db_packages)
 		elif os.path.isdir(_slack_db):
 			_host_distribution = SlackDistribution(_slack_db)
+		elif os.path.isdir(_arch_db):
+			_host_distribution = ArchDistribution(_arch_db)
 		else:
 			_host_distribution = Distribution()
 
