@@ -81,26 +81,6 @@ class Handler(object):
 		"""@deprecated: use tasks.wait_for_blocker instead"""
 		tasks.wait_for_blocker(blocker)
 	
-	def get_download(self, url, force = False, hint = None, factory = None):
-		"""Create a Download object to download 'url'.
-		@rtype: L{download.Download}
-		"""
-		import warnings
-		warnings.warn("Handler.get_download is deprecated (use Fetcher.download_url instead)", DeprecationWarning, stacklevel = 2)
-		if self.dry_run:
-			raise NeedDownload(url)
-
-		if factory is None:
-			dl = download.Download(url, hint)
-		else:
-			dl = factory(url, hint)
-		self.monitor_download(dl)
-		return dl
-
-	# Allows code that used to take a Handler and now expects a Fetcher to
-	# cope if it gets passed a Handler from some old code.
-	download_url = get_download
-
 	@tasks.async
 	def confirm_import_feed(self, pending, valid_sigs):
 		"""Sub-classes should override this method to interact with the user about new feeds.
