@@ -5,9 +5,11 @@ Executes a set of implementations as a program.
 # Copyright (C) 2009, Thomas Leonard
 # See the README file for details, or visit http://0install.net.
 
+from __future__ import print_function
+
 from zeroinstall import _
 import os, sys
-from logging import info
+from logging import info, debug
 from string import Template
 
 from zeroinstall.injector.model import SafeException, EnvironmentBinding, ExecutableBinding, Command, Dependency
@@ -20,6 +22,10 @@ def do_env_binding(binding, path):
 	@type binding: L{model.EnvironmentBinding}
 	@param path: the selected implementation
 	@type path: str"""
+	if binding.insert is not None and path is None:
+		# Skip insert bindings for package implementations
+		debug("not setting %s as we selected a package implementation", binding.name)
+		return
 	os.environ[binding.name] = binding.get_value(path,
 					os.environ.get(binding.name, None))
 	info("%s=%s", binding.name, os.environ[binding.name])
@@ -100,8 +106,12 @@ class Setup(object):
 
 	def build_command(self, command_iface, command_name, user_command = None):
 		"""Create a list of strings to be passed to exec to run the <command>s in the selections.
-		@param commands: the commands to be used (taken from selections is None)
-		@type commands: [L{model.Command}]
+		@param command_iface: the interface of the program being run
+		@type command_iface: str
+		@param command_name: the name of the command being run
+		@type command_name: str
+		@param user_command: a custom command to use instead
+		@type user_command: L{model.Command}
 		@return: the argument list
 		@rtype: [str]"""
 
@@ -165,56 +175,61 @@ class Setup(object):
 		return prog_args
 
 	def _get_implementation_path(self, impl):
+		if impl.id.startswith('package:'): return None
 		return impl.local_path or self.stores.lookup_any(impl.digests)
 
 	def prepare_env(self):
 		"""Do all the environment bindings in the selections (setting os.environ)."""
 		self._exec_bindings = []
 
-		def _do_bindings(impl, bindings, dep):
+		def _do_bindings(impl, bindings, iface):
 			for b in bindings:
-				self.do_binding(impl, b, dep)
+				self.do_binding(impl, b, iface)
 
 		def _do_deps(deps):
 			for dep in deps:
 				dep_impl = sels.get(dep.interface, None)
 				if dep_impl is None:
 					assert dep.importance != Dependency.Essential, dep
-				elif not dep_impl.id.startswith('package:'):
-					_do_bindings(dep_impl, dep.bindings, dep)
+				else:
+					_do_bindings(dep_impl, dep.bindings, dep.interface)
 
 		sels = self.selections.selections
 		for selection in sels.values():
-			_do_bindings(selection, selection.bindings, None)
+			_do_bindings(selection, selection.bindings, selection.interface)
 			_do_deps(selection.dependencies)
 
 			# Process commands' dependencies' bindings too
 			for command in selection.get_commands().values():
+				_do_bindings(selection, command.bindings, selection.interface)
 				_do_deps(command.requires)
 
 		# Do these after <environment>s, because they may do $-expansion
-		for binding, dep in self._exec_bindings:
-			self.do_exec_binding(binding, dep)
+		for binding, iface in self._exec_bindings:
+			self.do_exec_binding(binding, iface)
 		self._exec_bindings = None
 	
-	def do_binding(self, impl, binding, dep):
+	def do_binding(self, impl, binding, iface):
 		"""Called by L{prepare_env} for each binding.
 		Sub-classes may wish to override this.
 		@param impl: the selected implementation
 		@type impl: L{selections.Selection}
 		@param binding: the binding to be processed
 		@type binding: L{model.Binding}
-		@param dep: the dependency containing the binding, or None for implementation bindings
-		@type dep: L{model.Dependency}
+		@param iface: the interface containing impl
+		@type iface: L{model.Interface}
 		"""
 		if isinstance(binding, EnvironmentBinding):
 			do_env_binding(binding, self._get_implementation_path(impl))
 		elif isinstance(binding, ExecutableBinding):
-			self._exec_bindings.append((binding, dep))
+			if isinstance(iface, Dependency):
+				import warnings
+				warnings.warn("Pass an interface URI instead", DeprecationWarning, 2)
+				iface = iface.interface
+			self._exec_bindings.append((binding, iface))
 
-	def do_exec_binding(self, binding, dep):
-		if dep is None:
-			raise SafeException("<%s> can only appear within a <requires>" % binding.qdom.name)
+	def do_exec_binding(self, binding, iface):
+		assert iface is not None
 		name = binding.name
 		if '/' in name or name.startswith('.') or "'" in name:
 			raise SafeException("Invalid <executable> name '%s'" % name)
@@ -237,7 +252,7 @@ class Setup(object):
 			info("%s=%s", name, exec_path)
 
 		import json
-		args = self.build_command(dep.interface, binding.command)
+		args = self.build_command(iface, binding.command)
 		os.environ["0install-runenv-" + name] = json.dumps(args)
 
 	def _check_runenv(self):
@@ -312,7 +327,7 @@ def execute_selections(selections, prog_args, dry_run = False, main = None, wrap
 		prog_args = ['/bin/sh', '-c', wrapper + ' "$@"', '-'] + list(prog_args)
 
 	if dry_run:
-		print _("Would execute: %s") % ' '.join(prog_args)
+		print(_("Would execute: %s") % ' '.join(prog_args))
 	else:
 		info(_("Executing: %s"), prog_args)
 		sys.stdout.flush()
